@@ -1,6 +1,7 @@
 package Search::Elasticsearch::Client::5_0::Bulk;
-$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.80';
-use Moo;
+$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.80_1'; # TRIAL
+
+$Search::Elasticsearch::Client::5_0::Bulk::VERSION = '6.801';use Moo;
 with 'Search::Elasticsearch::Client::5_0::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
 use Search::Elasticsearch::Util qw(parse_params throw);
@@ -77,7 +78,7 @@ Search::Elasticsearch::Client::5_0::Bulk - A helper module for the Bulk API
 
 =head1 VERSION
 
-version 6.80
+version 6.80_1
 
 =head1 SYNOPSIS
 
